@@ -12,10 +12,4 @@ sub type    { $_[0]->{type} }
 sub module  { $_[0]->{module} }
 sub requirement { $_[0]->{requirement} }
 
-sub match_feature {
-    my($self, $identifier) = @_;
-    no warnings 'uninitialized';
-    $self->feature eq $identifier;
-}
-
 1;
